@@ -33,7 +33,7 @@ class WinConsoleError(Exception):
 DLL = ctypes.CDLL("consoleW.dll",winmode=0)
 
 def setXY(x,y):
-    if type(x)!=int or type(y)==int:
+    if type(x)!=int or type(y)!=int:
         raise WinConsoleError("you gived not is int",'getXY')
     DLL.setxy(x,y)
 def setColor(color):
